//
//  L7SEnterpriseBrowserController.m
//  sdkdemo
//
//  Created by Anthony Yu on 2014-05-26.
//  Copyright (c) 2014 CA Technologies. All rights reserved.
//

#import "L7SEnterpriseBrowserController.h"

#import "L7SEnterpriseApp.h"
#import "L7SClientManager.h"
#import "L7SWebViewController.h"
#import "L7SErrors.h"
#import "L7SClientManager.h"

@interface L7SEnterpriseBrowserController () <L7SEnterpriseAppProtocol, L7SClientProtocol> {
    NSArray *recipeImages;
}


@property (readwrite, nonatomic, strong) NSArray *apps;


@end

@implementation L7SEnterpriseBrowserController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)reload:(__unused id)sender {
    self.navigationItem.rightBarButtonItem.enabled = NO;
    
    
    [L7SEnterpriseApp enterpriseAppsWithBlock:^(NSArray *apps, NSError *error) {
        if (!error) {
            self.apps = apps;
            [self.collectionView reloadData];
        }
    }];

}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    //recipeImages = [NSArray arrayWithObjects:@"appA.png", @"appB.png", nil];
    
    self.title = NSLocalizedString(@"CA Enterprise Browser", nil);
    

    [[L7SClientManager sharedClientManager] setDelegate:self];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(didReceiveStatusUpdate:)
                                                 name:L7SDidReceiveStatusUpdateNotification
                                               object:nil];
    
    [self reload:nil];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}



- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section{
    return _apps.count;
}


- (UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath{
    static NSString *identifier = @"Cell";
    
    UICollectionViewCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:identifier forIndexPath:indexPath];
    
    UIImageView *appImageView = (UIImageView *)[cell viewWithTag:100];

    L7SEnterpriseApp *app = (L7SEnterpriseApp *)[self.apps objectAtIndex:(NSUInteger)indexPath.row];
    
    [app loadIconWithImageView:appImageView];
    
    NSLog(@"loading app: %@", app);
    app.delegate = self;
    
    return cell;
}

- (IBAction)logoutButtonPressed:(id)sender {
    [[L7SClientManager sharedClientManager] logoutDevice];
}

- (void) enterpriseWebApp: (L7SEnterpriseApp *) app{
   
   [self performSegueWithIdentifier: @"webviewSegue" sender: app];

}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([[segue identifier] isEqualToString:@"webviewSegue"])
    {
        L7SWebViewController *vc = [segue destinationViewController];
        vc.app = sender;

    }
}


- (void) viewWillAppear:(BOOL)animated{
    self.navigationItem.backBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Home" style:UIBarButtonItemStylePlain target:nil action:nil];
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Logout" style:UIBarButtonItemStylePlain target:self action:@selector(logoutButtonPressed:)];
    if([[L7SClientManager sharedClientManager] isDeviceLogin]){
        [self.navigationItem.rightBarButtonItem setEnabled:YES];
    }else{
        [self.navigationItem.rightBarButtonItem setEnabled:NO];
    }
     [self.navigationController setToolbarHidden:YES animated:YES];
}

- (void) didReceiveStatusUpdate:(NSNotification *) notification{
    NSLog(@"receive status update notification %@", notification);
    
    L7SClientState state = (L7SClientState)[[notification.userInfo objectForKey:L7SStatusUpdateKey] intValue];
    
    switch (state) {
        case L7SDidFinishRegistration:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Device Registered"
                                                            message:@"Device registered"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
            
        }break;
        case L7SDidFinishAuthentication:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Authentication"
                                                            message:@"Authenticated"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [self.navigationItem.rightBarButtonItem setEnabled:YES];
            [alert show];
            
            
            
        }break;
        case L7SDidFinishDeRegistration:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Device De-Registered"
                                                            message:@"Device de-registered"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
            
        }
        case L7SDidLogout:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Device Logout"
                                                            message:@"Device logged out"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [self.navigationItem.rightBarButtonItem setEnabled:NO];
            [alert show];
            
        }break;
        case L7SDidLogoff:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"App logoff"
                                                            message:@"App logged off"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
            
        }break;
        case L7SQRAuthenticationPollingStopped:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"QR Authentication"
                                                            message:@"QR Authentication Stopped"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
            
        }break;
        default:
            break;
            
    }
}



- (void)DidReceiveError:(NSError *)error{
    
    switch([error code]) {
        case L7SAuthenticationJWTError:
        {
            
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:[[error userInfo] objectForKey:NSLocalizedFailureReasonErrorKey]
                                                            message:[[error userInfo] objectForKey:NSLocalizedDescriptionKey]
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            break;
        }
        case  L7SAuthenticationLogoffError:
        {
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:[[error userInfo] objectForKey:NSLocalizedFailureReasonErrorKey]
                                                            message:[[error userInfo] objectForKey:NSLocalizedDescriptionKey]
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            break;
        }
        default:
        {
            //just show all errors for testing puporse
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:[[error userInfo] objectForKey:NSLocalizedFailureReasonErrorKey]
                                                            message:[[error userInfo] objectForKey:NSLocalizedDescriptionKey]
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            break;
        }
            break;
    }
    
    [self.navigationController popToRootViewControllerAnimated:YES];
    
}





@end
