cordova.define("com.l7tech.msso.L7SMssoSDKPlugin", function(require, exports, module) { //  Copyright (c) 2013 CA Technologies. All rights reserved.
//
var L7SMssoSDKPlugin = {
    
    /*
       The sysem will callback with status update whenever appropriate. The following is an example:
       
       L7SMssoSDKPlugin.registerStatusUpdate(statusUpdateHandler);
       
       function statusUpdateHandler(result) {
            if (result == L7SMssoSDKPlugin.L7SStatus.L7SDidLogoff) {
                //deal with it
            } else if (result == L7SMssoSDKPlugin.L7SStatus.L7SDidFinishAuthentication) {
                //deal with it
            } else if (result == L7SMssoSDKPlugin.L7SStatus.L7SDidLogout) {
                //deal with it
            } else if (result == L7SMssoSDKPlugin.L7SStatus.L7SDidFinishDeRegistration) {
                //deal with it
            }
        }
     
    */
    L7SStatus: {
        L7SDidFinishRegistration: 'L7SDidFinishRegistration',
        L7SDidFinishAuthentication: 'L7SDidFinishAuthentication',
        L7SDidFinishDeRegistration: 'L7SDidFinishDeRegistration',
        L7SDidLogout: 'L7SDidLogout',
        L7SDidLogoff: 'L7SDidLogoff'
    },
    
    /*
      The system will callback with an error object if there is any wrong. The error object is a dictionary with a key "errorCode"
     
      The following is an example to register for error callback and consume errorCode:
     
      L7SMssoSDKPlugin.registerErrorCallback(errorCallbackHanlder);
        function errorCallbackHanlder(result) {
            if (result.errorCode== L7SMssoSDKPlugin.L7SError.AuthenticationLoginError) {
                alert(result.errorCode);
            } else {
                alert(result.errorCode);
            }
        }
    */
    L7SError: {
        //authentication domain
        AuthenticationLoginError: -101,
        AuthenticationJWTError: -102,
        AuthenticationRefreshError: -103,
        LogoutError: -104,
        LogoffError: -105,
        SocialLoginError: -106,
    
        //registration domain
        RegistrationError: -201,
        DeRegistrationError: -202,
    
        //location domian
        LocationError: -301,
    
        //network domain
        NetworkError: -401,
    
        //http call domain
        HttpCallError: -501
    
    },
    
    
    /*
      Supported HTTP methods
     
    */
    HTTPMethod: {
        GET: 'GET',
        POST: 'POST',
        DELETE: 'DELETE',
        PUT: 'PUT'
    },
    
    /*
      Supported the content type
     
      Set the content-type in the headers to specify desired parameter encoding
    */
    CONTENT_TYPE :{
        FORM_URL:'application/x-www-form-urlencoded',
        JSON: 'application/json'
    },
    
    /*
     This is an HTTPClient Object for making an HTTP Call.
     
     1. To create an HTTP client object:
        var httpClient = new L7SMssoSDKPlugin.HttpClient('https://baseURL');
     
     2. To make a Get HTTP Call:
        httpClient.httpCall(successHandler, errorHandler, L7SMssoSDKPlugin.HTTPMethod.GET);
     
     Optionally, the following HTTPClient properties can be set (belows are examples):
       httpClient.path = '/protected/resource/products';
       httpClient.headers = {"Accept":"application/json", "Content-Type":L7SMssoSDKPlugin.CONTENT_TYPE.FORM_URL};
       httpClient.parameters = {"operation":"listProducts"};
     
     If the "headers" is not set, the default parameter encoding will be form_url encoding.
     
    */
    HttpClient: function (baseURL) {
        this.baseURL = baseURL;  // the URL to the resource
        this.path = '';      //optional, path to the resource
        this.headers={};     //optional, http request headers in Json foramt
        this.parameters={};  //optional, http request parameters in Json format
        
        /*
         The httpCall function takes three parameters: request success handler, request failure handler, and a supported HTTP method.
         
         1) The success handler is a fucntion accepts string as a parameter, for example:
         
           function httpCallPluginResultHandler (result) {
                  //process the result based on the format
            }
         
         2) The failure hander accepts an error object as a dictionary with a key "errorCode", for example:
         
           function nativePluginErrorHandler (error) {
                //the errorCode in this case, L7SMssoSDKPlugin.L7SError.HttpCallError
                alert("ERROR: \r\n"+error.errorCode );
           }
         
         3) The method parameter is one of supported HTTP methods, for example: L7SMssoSDKPlugin.HTTPMethod.GET
         
        */
        this.httpCall = function (success, fail, method){
            return Cordova.exec(success, fail, "com.l7tech.msso.L7SMssoSDKPlugin", "httpCall", [method, this.baseURL, this.path, this.headers, this.parameters]);
        };
    },

    
    //Method to logout device
    logoutDevice: function () {
        return Cordova.exec(null, null, "com.l7tech.msso.L7SMssoSDKPlugin", "logoutDevice", []);
    },
    
    //Method to deregister device
    deRegister: function () {
        return Cordova.exec(null, null, "com.l7tech.msso.L7SMssoSDKPlugin", "deRegister", []);
    },
    
    //method to logoff app
    logoffApp: function () {
        return Cordova.exec(null, null, "com.l7tech.msso.L7SMssoSDKPlugin", "logoffApp", []);
    },
    
    /*
      Method to check if the app is logged in
     
      return boolean
    */
    isLogin: function (resultHandler) {
        return Cordova.exec(resultHandler, null, "com.l7tech.msso.L7SMssoSDKPlugin", "isLogin", []);
    },
    
    /*
      Method to check if the app is logged on
     
      return boolean
    */
    isAppLogon: function (resultHandler) {
       return Cordova.exec(resultHandler, null, "com.l7tech.msso.L7SMssoSDKPlugin", "isAppLogon", []);
    },
    
    /*
      Method to check if the device is registered.
     
      return boolean
    */
    isDeviceRegistered:function (resultHandler) {
        return Cordova.exec(resultHandler, null, "com.l7tech.msso.L7SMssoSDKPlugin", "isDeviceRegistered", []);
    },
    
    /*
      Register system status update.
    
      The callback object is a JSON object that contains a dictionary with L7SStatus enum as the key
    */
    registerStatusUpdate:function (statusUpdateHandler){
        return Cordova.exec(statusUpdateHandler, null, "com.l7tech.msso.L7SMssoSDKPlugin", "registerStatusUpdate", []);
    },
    
    /*
      Register error callback.  
     
      The callback object is a JSON object that contains a dictionary with "errorCode" as the key
    */
    registerErrorCallback:function (errorCallbackHandler){
        return Cordova.exec(errorCallbackHandler, null, "com.l7tech.msso.L7SMssoSDKPlugin", "registerErrorCallback", []);
    }
    
};

module.exports = L7SMssoSDKPlugin;
});
