//
//  ViewController.m
//  HelloWorld
//
//  Created by Anthony Yu on 2014-12-23.
//  Copyright (c) 2014 Anthony. All rights reserved.
//

#import "ViewController.h"
#import "L7SHTTPClient.h"
#import "L7SAFJSONRequestOperation.h"
#import "L7SClientManager.h"
#import "L7SErrors.h"


@interface ViewController () <L7SClientProtocol> {
    int _counter;
}

@property (weak, nonatomic) IBOutlet UILabel *displayLabel;

@property (weak, nonatomic) IBOutlet UILabel *helloLabel;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    
     [[L7SClientManager sharedClientManager] setDelegate:self];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(didReceiveStatusUpdate:)
                                                 name:L7SDidReceiveStatusUpdateNotification
                                               object:nil];
    
    [self updateDisplayLable];

}

- (void) updateDisplayLable{
    if([[L7SClientManager sharedClientManager] isAppLogon]){
        
        L7SHTTPClient *httpClient = [[ L7SHTTPClient alloc] initWithBaseURL:[NSURL URLWithString:@"https://hawking.l7tech.com:8443"]];
        
        [httpClient registerHTTPOperationClass:[L7SAFJSONRequestOperation class]];
        
        [httpClient setDefaultHeader:@"Accept" value:@"application/json"];
        
        [httpClient getPath:@"/openid/connect/v1/userinfo" parameters:nil success:^(L7SAFHTTPRequestOperation *operation, id responseObject) {
            
            
            NSLog(@"Result %@", responseObject);
            [self.helloLabel setText:[NSString stringWithFormat:@"Hello %@", [responseObject objectForKey:@"family_name" ]]];
            
        } failure:^(L7SAFHTTPRequestOperation *operation, NSError *error) {
            
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                            message:[[error userInfo] objectForKey:NSLocalizedDescriptionKey]
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            NSLog(@"Error %@", error);
            
        }];
    }
    
}

- (void) didReceiveStatusUpdate:(NSNotification *) notification{
    NSLog(@"receive status update notification %@", notification);
    
    L7SClientState state = (L7SClientState)[[notification.userInfo objectForKey:L7SStatusUpdateKey] intValue];
    
    switch (state) {
        case L7SDidFinishRegistration:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Device Registered"
                                                            message:@"Device registered"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [self updateDisplayLable];
            
            [alert show];
            
        }break;
        case L7SDidFinishAuthentication:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Authentication"
                                                            message:@"Authenticated"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [self updateDisplayLable];
            [alert show];
            
            
        }break;
        case L7SDidFinishDeRegistration:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Device De-Registered"
                                                            message:@"Please kill the app to achieve a clean device reset before any other activities"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
        }
        case L7SDidLogout:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Device Logout"
                                                            message:@"Device logged out"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
        }break;
        case L7SDidLogoff:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"App logoff"
                                                            message:@"App logged off"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
        }break;
        case L7SQRAuthenticationPollingStopped:{
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"QR Authentication"
                                                            message:@"QR Authentication Stopped"
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            
            
        }break;
        default:
            break;
            
    }
}

- (void)DidReceiveError:(NSError *)error{
    
    switch([error code]) {
        case L7SAuthenticationJWTError:
        {
            
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:[[error userInfo] objectForKey:NSLocalizedFailureReasonErrorKey]
                                                            message:[[error userInfo] objectForKey:NSLocalizedDescriptionKey]
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            break;
        }
        case  L7SAuthenticationLogoffError:
        {
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:[[error userInfo] objectForKey:NSLocalizedFailureReasonErrorKey]
                                                            message:[[error userInfo] objectForKey:NSLocalizedDescriptionKey]
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            break;
        }
        default:
        {
            //just show all errors for testing puporse
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:[[error userInfo] objectForKey:NSLocalizedFailureReasonErrorKey]
                                                            message:[[error userInfo] objectForKey:NSLocalizedDescriptionKey]
                                                           delegate:nil
                                                  cancelButtonTitle:@"OK"
                                                  otherButtonTitles:nil];
            [alert show];
            break;
        }
            break;
    }
    
    
}



- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
- (IBAction)buttonPressed:(id)sender {
    [self.displayLabel setText:[NSString stringWithFormat:@"tapped :%i", ++_counter]];
}

@end
