//
//  L7SEnterpriseApps.h
//  sdkdemo
//
//  Created by Anthony Yu on 2014-05-27.
//  Copyright (c) 2014 CA Technologies. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 This class features enterprise browser capabilities.  It retrieves enterprise apps that can be configured on the server side, and encapsulates session sharing among web-based mobile apps and native mobile apps,
 */


@protocol L7SEnterpriseAppProtocol;

@interface L7SEnterpriseApp : NSObject<UIWebViewDelegate>

/**
 delegate that implements L7SEnterpriseAppProtocol
 */
@property id<L7SEnterpriseAppProtocol> delegate;

/**
 This is the app's identifier
 */
@property (readonly, nonatomic) NSString *appId;

/**
 This is the app's display name
 */
@property (readonly, nonatomic) NSString *appName;


/**
  This is a JSON object contains custom metadata.

 */
@property (readonly, nonatomic) id customFields;


/**
 This class method returns a list of L7SEnterprise app objects or an error if failed to retrieve the apps
 
  @param block a callback block receiving a list of apps or an error
 */
+ (void) enterpriseAppsWithBlock:(void (^)(NSArray *apps, NSError *error))block;

/**
 This method loads an icon into the image view provided
 
 @param imageView an imageView object contains the app icon
 */
- (void) loadIconWithImageView:(UIImageView *) imageView;


/**
 This method loads a webapp into a webview
 
 @param webView a webView loading  the web app
 */
- (void) loadWebApp:(UIWebView *) webView;

@end


@protocol L7SEnterpriseAppProtocol <NSObject>


/**
 This is the protocol for an app to implement to receive a callback when an enterrpise webView needs to be loaded
 
 @param app the app object needs to be loaded as a webapp
 
 */
- (void) enterpriseWebApp: (L7SEnterpriseApp *) app;

@end